# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\x1d\n\x0c\x42oolResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"\x1f\n\x0e\x44oubleResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"\x1c\n\x0bIntResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1f\n\x0eStringResponse\x12\r\n\x05value\x18\x01 \x01(\t\"\xdd\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\x12\x13\n\x0bis_modified\x18\x05 \x01(\x08\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\xcb\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x13\n\x0bis_modified\x18\x06 \x01(\x08\x12\x15\n\ris_integrated\x18\x07 \x01(\x08\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"\x8a\x01\n\x0c\x44\x65viceIOInfo\x12\x1d\n\x15number_analog_outputs\x18\x02 \x01(\x05\x12\x1c\n\x14number_analog_inputs\x18\x03 \x01(\x05\x12\x1e\n\x16number_digital_outputs\x18\x04 \x01(\x05\x12\x1d\n\x15number_digital_inputs\x18\x05 \x01(\x05\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\">\n\x14StreamAxisDefinition\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x11\n\taxis_type\x18\x02 \x01(\x05\"<\n\x1aInvalidPacketExceptionData\x12\x0e\n\x06packet\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\">\n\"DeviceAddressConflictExceptionData\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"D\n MovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"J\n&StreamMovementInterruptedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"?\n\x1bMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"E\n!StreamMovementFailedExceptionData\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"B\n\x1cStreamExecutionExceptionData\x12\x12\n\nerror_flag\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"0\n\x1cInvalidResponseExceptionData\x12\x10\n\x08response\x18\x01 \x01(\t\"m\n\x1a\x43ommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\t\x12\x12\n\nreply_flag\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x07 \x01(\t\"9\n BinaryCommandFailedExceptionData\x12\x15\n\rresponse_data\x18\x01 \x01(\x05\"o\n\x1fSetPeripheralStateExceptionData\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x10\n\x08settings\x18\x02 \x03(\t\x12\x14\n\x0cservo_tuning\x18\x03 \x01(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\"\xe1\x01\n\x1bSetDeviceStateExceptionData\x12L\n\x0bperipherals\x18\x02 \x03(\x0b\x32\x37.zaber.motion.protobufs.SetPeripheralStateExceptionData\x12\x10\n\x08settings\x18\x03 \x03(\t\x12\x16\n\x0estream_buffers\x18\x04 \x03(\t\x12\x10\n\x08triggers\x18\x05 \x03(\t\x12\x11\n\tip_config\x18\x06 \x01(\t\x12\x14\n\x0cservo_tuning\x18\x07 \x01(\t\x12\x0f\n\x07storage\x18\x08 \x03(\t\"g\n\x1b\x43ommandTooLongExceptionData\x12\x0b\n\x03\x66it\x18\x01 \x01(\t\x12\x11\n\tremainder\x18\x02 \x01(\t\x12\x13\n\x0bpacket_size\x18\x03 \x01(\x05\x12\x13\n\x0bpackets_max\x18\x04 \x01(\x05\"V\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\x12\x1e\n\x16return_error_with_data\x18\x03 \x01(\x08\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"%\n\x10TestResponseLong\x12\x11\n\tdata_pong\x18\x01 \x03(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"&\n\x16SetInternalModeRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x08\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"+\n\x1b\x44\x65viceDbFailedExceptionData\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\xa7\x02\n\x14OpenInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x11\n\ttransport\x18\x06 \x01(\x05\x12 \n\x18reject_routed_connection\x18\x07 \x01(\x08\x12\x10\n\x08\x63loud_id\x18\x08 \x01(\t\x12\x17\n\x0f\x63onnection_name\x18\t \x01(\t\x12\r\n\x05realm\x18\n \x01(\t\x12\r\n\x05token\x18\x0b \x01(\t\x12\x0b\n\x03\x61pi\x18\x0c \x01(\t\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15InterfaceEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"C\n\x1aSetInterfaceTimeoutRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"N\n\"SetInterfaceChecksumEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"F\n\x10\x41xisEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\x83\x01\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xd0\x02\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\x12\x10\n\x08velocity\x18\x08 \x01(\x01\x12\x15\n\rvelocity_unit\x18\t \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\n \x01(\x01\x12\x19\n\x11\x61\x63\x63\x65leration_unit\x18\x0b \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"C\n\x12\x44\x65viceOnAllRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"/\n\x13\x44\x65viceOnAllResponse\x12\x18\n\x10\x64\x65vice_addresses\x18\x01 \x03(\x05\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"Z\n\x1c\x44\x65viceGetAllDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\"/\n\x1d\x44\x65viceGetAllDigitalIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x08\"Y\n\x1b\x44\x65viceGetAllAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\".\n\x1c\x44\x65viceGetAllAnalogIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"o\n\x19\x44\x65viceGetDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"n\n\x18\x44\x65viceGetAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"Y\n!DeviceSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x08\"X\n DeviceSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x01\"l\n\x1d\x44\x65viceSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x08\"k\n\x1c\x44\x65viceSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\"\x94\x01\n\x1b\x44\x65viceConvertSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\x12\x13\n\x0b\x66rom_native\x18\x07 \x01(\x08\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"p\n\x1a\x44\x65viceSetSettingStrRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\"f\n\x15LockstepEnableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"r\n\x16LockstepDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"\xe1\x02\n\x13LockstepMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12\x42\n\x04type\x18\x05 \x01(\x0e\x32\x34.zaber.motion.protobufs.LockstepMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x08 \x01(\t\x12\x10\n\x08velocity\x18\t \x01(\x01\x12\x15\n\rvelocity_unit\x18\n \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x0b \x01(\x01\x12\x19\n\x11\x61\x63\x63\x65leration_unit\x18\x0c \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"}\n\x1cLockstepWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"W\n\x14LockstepEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"N\n\x0cLockstepAxes\x12\x0e\n\x06\x61xis_1\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x61xis_3\x18\x03 \x01(\x05\x12\x0e\n\x06\x61xis_4\x18\x04 \x01(\x05\".\n\x1eLockstepGetAxisNumbersResponse\x12\x0c\n\x04\x61xes\x18\x01 \x03(\x05\"i\n\x18LockstepGetTwistsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"+\n\x19LockstepGetTwistsResponse\x12\x0e\n\x06twists\x18\x01 \x03(\x01\"j\n\x19LockstepGetOffsetsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"-\n\x1aLockstepGetOffsetsResponse\x12\x0f\n\x07offsets\x18\x01 \x03(\x01\"d\n\x1dOscilloscopeAddChannelRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\"S\n\x1cOscilloscopeStartStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\r\n\x05start\x18\x03 \x01(\x08\",\n\x18OscilloscopeReadResponse\x12\x10\n\x08\x64\x61ta_ids\x18\x01 \x03(\x05\"-\n\x1aOscilloscopeDataIdentifier\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\"E\n\x1dOscilloscopeCaptureProperties\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\x13\n\x0b\x61xis_number\x18\x02 \x01(\x05\";\n\x1aOscilloscopeDataGetRequest\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\x12\x0c\n\x04unit\x18\x02 \x01(\t\"T\n$OscilloscopeDataGetSampleTimeRequest\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\x05\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x05\"2\n\"OscilloscopeDataGetSamplesResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"_\n\x16StreamSetupLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"\x96\x01\n\x1fStreamSetupLiveCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12:\n\x04\x61xes\x18\x04 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"w\n\x17StreamSetupStoreRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x05 \x03(\x05\"\xae\x01\n StreamSetupStoreCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12:\n\x04\x61xes\x18\x05 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\x8a\x01\n$StreamSetupStoreArbitraryAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x12\n\naxes_count\x18\x05 \x01(\x05\"c\n\x11StreamCallRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\"\xf8\x01\n\x11StreamLineRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12<\n\x04type\x18\x04 \x01(\x0e\x32..zaber.motion.protobufs.StreamLineRequest.Type\x12\x35\n\x08\x65ndpoint\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x06 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xb1\x03\n\x10StreamArcRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12;\n\x04type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.StreamArcRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_x\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_y\x18\t \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\n \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xcf\x02\n\x13StreamCircleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12>\n\x04type\x18\x04 \x01(\x0e\x32\x30.zaber.motion.protobufs.StreamCircleRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x08 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x7f\n\x1dStreamWaitDigitalInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"\x91\x01\n\x1cStreamWaitAnalogInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\x11\n\tcondition\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\"\x7f\n\x1dStreamSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"~\n\x1cStreamSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x01\"s\n StreamToggleDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"l\n!StreamSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x08\"k\n StreamSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0e\n\x06values\x18\x04 \x03(\x01\"h\n\x11StreamWaitRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n\x1aStreamWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"M\n\x12StreamEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"S\n\x15StreamGetAxesResponse\x12:\n\x04\x61xes\x18\x01 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"a\n\x18StreamGetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"t\n\x18StreamSetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x11\n\tmax_speed\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"r\n)StreamGetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"\x97\x01\n)StreamSetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12#\n\x1bmax_tangential_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n*StreamGetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"\x99\x01\n*StreamSetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12$\n\x1cmax_centripetal_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"X\n\x1dStreamBufferGetContentRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"6\n\x1eStreamBufferGetContentResponse\x12\x14\n\x0c\x62uffer_lines\x18\x01 \x03(\t\"S\n\x18StreamBufferEraseRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"g\n\x1bStreamGenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\"j\n StreamGenericCommandBatchRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\r\n\x05\x62\x61tch\x18\x04 \x03(\t\"c\n\x14\x42inaryReplyOnlyEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\xbb\x01\n\x1aOpenBinaryInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x17\n\x0fuse_message_ids\x18\x06 \x01(\x08\"i\n\x1aUnknownBinaryResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\x82\x01\n\x14GenericBinaryRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x01\"F\n\rBinaryMessage\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x05\"R\n\x17\x42inaryMessageCollection\x12\x37\n\x08messages\x18\x02 \x03(\x0b\x32%.zaber.motion.protobufs.BinaryMessage\":\n\x12\x44\x65viceEmptyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xd9\x02\n\x14\x42inaryDeviceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x15\n\ris_peripheral\x18\x06 \x01(\x08\x12\x15\n\rperipheral_id\x18\x07 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x08 \x01(\t\x12L\n\x0b\x64\x65vice_type\x18\t \x01(\x0e\x32\x37.zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType\"1\n\nDeviceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\x99\x01\n\x1d\x42inaryGenericWithUnitsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x01\x12\x11\n\tfrom_unit\x18\x05 \x01(\t\x12\x0f\n\x07to_unit\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x01\"^\n\x17\x42inaryDeviceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"\xda\x01\n\x17\x42inaryDeviceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x46\n\x04type\x18\x04 \x01(\x0e\x32\x38.zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"^\n\x17\x42inaryDeviceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"K\n\x19\x42inaryDeviceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"-\n\x1a\x42inaryDeviceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"d\n\x1d\x42inaryDeviceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"s\n\x1d\x42inaryDeviceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"2\n\x1a\x43ustomInterfaceReadRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"D\n\x1b\x43ustomInterfaceWriteRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\x1b\x43ustomInterfaceOpenResponse\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\"J\n\x1b\x43ustomInterfaceCloseRequest\x12\x14\n\x0ctransport_id\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"W\n\x12\x43\x61nSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\"=\n\x17\x43\x61nSetStateAxisResponse\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"p\n\x19\x43\x61nSetStateDeviceResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x44\n\x0b\x61xis_errors\x18\x02 \x03(\x0b\x32/.zaber.motion.protobufs.CanSetStateAxisResponse\"i\n\x0fSetStateRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_only\x18\x05 \x01(\x08\"Z\n\x12ServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\"/\n\x10ServoTuningParam\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\"g\n\x0cParamsetInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x38\n\x06params\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"\x9e\x01\n\x15SetServoTuningRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12?\n\rtuning_params\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"n\n\x0cLoadParamset\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x13\n\x0bto_paramset\x18\x04 \x01(\x05\x12\x15\n\rfrom_paramset\x18\x05 \x01(\x05\"\x8d\x01\n\x18SetServoTuningPIDRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\t\n\x01p\x18\x05 \x01(\x01\x12\t\n\x01i\x18\x06 \x01(\x01\x12\t\n\x01\x64\x18\x07 \x01(\x01\x12\n\n\x02\x66\x63\x18\x08 \x01(\x01\"W\n\tPidTuning\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\t\n\x01p\x18\x03 \x01(\x01\x12\t\n\x01i\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01\x12\n\n\x02\x66\x63\x18\x06 \x01(\x01\"\xc2\x01\n\x0fSetSimpleTuning\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x10\n\x08paramset\x18\x04 \x01(\x05\x12\x15\n\rcarriage_mass\x18\x05 \x01(\x01\x12\x11\n\tload_mass\x18\x06 \x01(\x01\x12?\n\rtuning_params\x18\x07 \x03(\x0b\x32(.zaber.motion.protobufs.ServoTuningParam\"d\n\x1bSimpleTuningParamDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmin_label\x18\x02 \x01(\t\x12\x11\n\tmax_label\x18\x03 \x01(\t\x12\x11\n\tdata_type\x18\x04 \x01(\t\"m\n&GetSimpleTuningParamDefinitionResponse\x12\x43\n\x06params\x18\x01 \x03(\x0b\x32\x33.zaber.motion.protobufs.SimpleTuningParamDefinition\"\x95\x01\n\x17TranslatorCreateRequest\x12@\n\ndefinition\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.TranslatorDefinition\x12\x38\n\x06\x63onfig\x18\x02 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"1\n\x18TranslatorCreateResponse\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"O\n\x18TranslatorAxisDefinition\x12\x15\n\rperipheral_id\x18\x01 \x01(\x05\x12\x1c\n\x14microstep_resolution\x18\x02 \x01(\x05\"\xa1\x01\n\x14TranslatorDefinition\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12>\n\x04\x61xes\x18\x02 \x03(\x0b\x32\x30.zaber.motion.protobufs.TranslatorAxisDefinition\x12\x36\n\tmax_speed\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"\xac\x01\n\x10TranslatorConfig\x12\x44\n\raxis_mappings\x18\x01 \x03(\x0b\x32-.zaber.motion.protobufs.TranslatorAxisMapping\x12R\n\x14\x61xis_transformations\x18\x02 \x03(\x0b\x32\x34.zaber.motion.protobufs.TranslatorAxisTransformation\"@\n\x15TranslatorAxisMapping\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x12\n\naxis_index\x18\x02 \x01(\x05\"~\n\x1cTranslatorAxisTransformation\x12\x13\n\x0b\x61xis_letter\x18\x01 \x01(\t\x12\x0f\n\x07scaling\x18\x02 \x01(\x01\x12\x38\n\x0btranslation\x18\x03 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\"B\n\x1aTranslatorTranslateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\r\n\x05\x62lock\x18\x02 \x01(\t\"I\n\x10TranslateMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x12\n\nfrom_block\x18\x02 \x01(\x05\x12\x10\n\x08to_block\x18\x03 \x01(\x05\"k\n\x1bTranslatorTranslateResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\x12:\n\x08warnings\x18\x02 \x03(\x0b\x32(.zaber.motion.protobufs.TranslateMessage\"@\n\x18GCodeSyntaxExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"C\n\x1bGCodeExecutionExceptionData\x12\x12\n\nfrom_block\x18\x01 \x01(\x05\x12\x10\n\x08to_block\x18\x02 \x01(\x05\"L\n\x1aTranslatorFlushLiveRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x02 \x01(\x08\"+\n\x17TranslatorFlushResponse\x12\x10\n\x08\x63ommands\x18\x01 \x03(\t\"\x90\x01\n\x1bTranslatorCreateLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"\x91\x01\n!TranslatorCreateFromDeviceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x03 \x03(\x05\x12\x38\n\x06\x63onfig\x18\x04 \x01(\x0b\x32(.zaber.motion.protobufs.TranslatorConfig\"/\n\x16TranslatorEmptyRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\"^\n TranslatorSetTraverseRateRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x15\n\rtraverse_rate\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t\"g\n TranslatorSetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"U\n TranslatorGetAxisPositionRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x02 \x01(\t\x12\x0c\n\x04unit\x18\x03 \x01(\t\"n\n\x1eTranslatorGetAxisOffsetRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x19\n\x11\x63oordinate_system\x18\x02 \x01(\t\x12\x0c\n\x04\x61xis\x18\x03 \x01(\t\x12\x0c\n\x04unit\x18\x04 \x01(\t\"R\n$TranslatorSetFeedRateOverrideRequest\x12\x15\n\rtranslator_id\x18\x01 \x01(\x05\x12\x13\n\x0b\x63oefficient\x18\x02 \x01(\x01\"y\n\x17\x44\x65viceSetStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12\x0e\n\x06\x65ncode\x18\x06 \x01(\x08\"j\n\x17\x44\x65viceGetStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65\x63ode\x18\x05 \x01(\x08\"o\n\x1d\x44\x65viceSetStorageNumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\"m\n\x1b\x44\x65viceSetStorageBoolRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x08\"W\n\x14\x44\x65viceStorageRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\"\xa1\x01\n\x1f\x44\x65viceSetUnitConversionsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0b\n\x03key\x18\x04 \x01(\t\x12=\n\x0b\x63onversions\x18\x05 \x03(\x0b\x32(.zaber.motion.protobufs.ConversionFactor\"@\n\x10\x43onversionFactor\x12\x0f\n\x07setting\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04unit\x18\x03 \x01(\t*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\xf7\x07\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1b\n\x17\x44\x45VICE_ADDRESS_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\r\n\tIO_FAILED\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\r\n\tOS_FAILED\x10\x14\x12\x12\n\x0eINTERNAL_ERROR\x10\x16\x12\x19\n\x15\x42INARY_COMMAND_FAILED\x10\x18\x12\x15\n\x11\x43OMMAND_PREEMPTED\x10\x19\x12\x18\n\x14LOCKSTEP_NOT_ENABLED\x10\x1a\x12\x14\n\x10LOCKSTEP_ENABLED\x10\x1b\x12\x1b\n\x17IO_CHANNEL_OUT_OF_RANGE\x10\x1c\x12\x15\n\x11SETTING_NOT_FOUND\x10\x1d\x12\x0f\n\x0bSTREAM_MODE\x10\x1e\x12\x14\n\x10STREAM_EXECUTION\x10\x1f\x12\x1a\n\x16STREAM_MOVEMENT_FAILED\x10 \x12\x17\n\x13STREAM_SETUP_FAILED\x10!\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\"\x12\x1f\n\x1bSTREAM_MOVEMENT_INTERRUPTED\x10#\x12\x16\n\x12INVALID_PARK_STATE\x10$\x12\x14\n\x10SERIAL_PORT_BUSY\x10%\x12\x1a\n\x16TRANSPORT_ALREADY_USED\x10&\x12\x1f\n\x1bSET_PERIPHERAL_STATE_FAILED\x10\'\x12\x1b\n\x17SET_DEVICE_STATE_FAILED\x10(\x12\x11\n\rG_CODE_SYNTAX\x10)\x12\x14\n\x10G_CODE_EXECUTION\x10*\x12\x15\n\x11INVALID_OPERATION\x10+\x12\x14\n\x10\x43OMMAND_TOO_LONG\x10,\x12\x14\n\x10NO_VALUE_FOR_KEY\x10-*Q\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\n\n\x06\x43USTOM\x10\x02\x12\x07\n\x03IOT\x10\x03\x12\x11\n\rNETWORK_SHARE\x10\x04\x42$Z\"./protobufs;zaber_motion_protobufsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protobufs.main_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"./protobufs;zaber_motion_protobufs'
  _MESSAGETYPE._serialized_start=20022
  _MESSAGETYPE._serialized_end=20067
  _ERRORS._serialized_start=20070
  _ERRORS._serialized_end=21085
  _INTERFACETYPE._serialized_start=21087
  _INTERFACETYPE._serialized_end=21168
  _REQUEST._serialized_start=48
  _REQUEST._serialized_end=74
  _RESPONSE._serialized_start=77
  _RESPONSE._serialized_end=262
  _RESPONSE_RESPONSETYPE._serialized_start=229
  _RESPONSE_RESPONSETYPE._serialized_end=262
  _EVENT._serialized_start=264
  _EVENT._serialized_end=286
  _EMPTYREQUEST._serialized_start=288
  _EMPTYREQUEST._serialized_end=302
  _BOOLRESPONSE._serialized_start=304
  _BOOLRESPONSE._serialized_end=333
  _DOUBLERESPONSE._serialized_start=335
  _DOUBLERESPONSE._serialized_end=366
  _INTRESPONSE._serialized_start=368
  _INTRESPONSE._serialized_end=396
  _STRINGRESPONSE._serialized_start=398
  _STRINGRESPONSE._serialized_end=429
  _AXISIDENTITY._serialized_start=432
  _AXISIDENTITY._serialized_end=653
  _AXISIDENTITY_AXISTYPE._serialized_start=606
  _AXISIDENTITY_AXISTYPE._serialized_end=653
  _DEVICEIDENTITY._serialized_start=656
  _DEVICEIDENTITY._serialized_end=859
  _FIRMWAREVERSION._serialized_start=861
  _FIRMWAREVERSION._serialized_end=923
  _DEVICEIOINFO._serialized_start=926
  _DEVICEIOINFO._serialized_end=1064
  _MEASUREMENT._serialized_start=1066
  _MEASUREMENT._serialized_end=1108
  _STREAMAXISDEFINITION._serialized_start=1110
  _STREAMAXISDEFINITION._serialized_end=1172
  _INVALIDPACKETEXCEPTIONDATA._serialized_start=1174
  _INVALIDPACKETEXCEPTIONDATA._serialized_end=1234
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_start=1236
  _DEVICEADDRESSCONFLICTEXCEPTIONDATA._serialized_end=1298
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1300
  _MOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1368
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_start=1370
  _STREAMMOVEMENTINTERRUPTEDEXCEPTIONDATA._serialized_end=1444
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1446
  _MOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1509
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_start=1511
  _STREAMMOVEMENTFAILEDEXCEPTIONDATA._serialized_end=1580
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_start=1582
  _STREAMEXECUTIONEXCEPTIONDATA._serialized_end=1648
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_start=1650
  _INVALIDRESPONSEEXCEPTIONDATA._serialized_end=1698
  _COMMANDFAILEDEXCEPTIONDATA._serialized_start=1700
  _COMMANDFAILEDEXCEPTIONDATA._serialized_end=1809
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_start=1811
  _BINARYCOMMANDFAILEDEXCEPTIONDATA._serialized_end=1868
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_start=1870
  _SETPERIPHERALSTATEEXCEPTIONDATA._serialized_end=1981
  _SETDEVICESTATEEXCEPTIONDATA._serialized_start=1984
  _SETDEVICESTATEEXCEPTIONDATA._serialized_end=2209
  _COMMANDTOOLONGEXCEPTIONDATA._serialized_start=2211
  _COMMANDTOOLONGEXCEPTIONDATA._serialized_end=2314
  _TESTREQUEST._serialized_start=2316
  _TESTREQUEST._serialized_end=2402
  _TESTRESPONSE._serialized_start=2404
  _TESTRESPONSE._serialized_end=2437
  _TESTRESPONSELONG._serialized_start=2439
  _TESTRESPONSELONG._serialized_end=2476
  _TESTEVENT._serialized_start=2478
  _TESTEVENT._serialized_end=2503
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_start=2505
  _TOOLSLISTSERIALPORTSRESPONSE._serialized_end=2550
  _SETINTERNALMODEREQUEST._serialized_start=2552
  _SETINTERNALMODEREQUEST._serialized_end=2590
  _SETDEVICEDBSOURCEREQUEST._serialized_start=2592
  _SETDEVICEDBSOURCEREQUEST._serialized_end=2665
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_start=2667
  _TOGGLEDEVICEDBSTOREREQUEST._serialized_end=2738
  _DEVICEDBFAILEDEXCEPTIONDATA._serialized_start=2740
  _DEVICEDBFAILEDEXCEPTIONDATA._serialized_end=2783
  _OPENINTERFACEREQUEST._serialized_start=2786
  _OPENINTERFACEREQUEST._serialized_end=3081
  _OPENINTERFACERESPONSE._serialized_start=3083
  _OPENINTERFACERESPONSE._serialized_end=3128
  _INTERFACEEMPTYREQUEST._serialized_start=3130
  _INTERFACEEMPTYREQUEST._serialized_end=3175
  _SETINTERFACETIMEOUTREQUEST._serialized_start=3177
  _SETINTERFACETIMEOUTREQUEST._serialized_end=3244
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_start=3246
  _SETINTERFACECHECKSUMENABLEDREQUEST._serialized_end=3324
  _AXISEMPTYREQUEST._serialized_start=3326
  _AXISEMPTYREQUEST._serialized_end=3396
  _GENERICCOMMANDREQUEST._serialized_start=3399
  _GENERICCOMMANDREQUEST._serialized_end=3530
  _GENERICCOMMANDRESPONSE._serialized_start=3533
  _GENERICCOMMANDRESPONSE._serialized_end=3733
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_start=3735
  _GENERICCOMMANDRESPONSECOLLECTION._serialized_end=3836
  _UNKNOWNRESPONSEEVENT._serialized_start=3839
  _UNKNOWNRESPONSEEVENT._serialized_end=4059
  _ALERTEVENT._serialized_start=4062
  _ALERTEVENT._serialized_end=4193
  _DISCONNECTEDEVENT._serialized_start=4195
  _DISCONNECTEDEVENT._serialized_end=4311
  _DEVICERENUMBERREQUEST._serialized_start=4313
  _DEVICERENUMBERREQUEST._serialized_end=4381
  _DEVICEDETECTREQUEST._serialized_start=4383
  _DEVICEDETECTREQUEST._serialized_end=4452
  _DEVICEDETECTRESPONSE._serialized_start=4454
  _DEVICEDETECTRESPONSE._serialized_end=4493
  _DEVICEHOMEREQUEST._serialized_start=4495
  _DEVICEHOMEREQUEST._serialized_end=4591
  _DEVICEWAITUNTILIDLEREQUEST._serialized_start=4593
  _DEVICEWAITUNTILIDLEREQUEST._serialized_end=4703
  _DEVICEMOVEREQUEST._serialized_start=4706
  _DEVICEMOVEREQUEST._serialized_end=5042
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_start=4987
  _DEVICEMOVEREQUEST_MOVETYPE._serialized_end=5042
  _DEVICESTOPREQUEST._serialized_start=5044
  _DEVICESTOPREQUEST._serialized_end=5140
  _DEVICEONALLREQUEST._serialized_start=5142
  _DEVICEONALLREQUEST._serialized_end=5209
  _DEVICEONALLRESPONSE._serialized_start=5211
  _DEVICEONALLRESPONSE._serialized_end=5258
  _DEVICEGETWARNINGSREQUEST._serialized_start=5260
  _DEVICEGETWARNINGSREQUEST._serialized_end=5353
  _DEVICEGETWARNINGSRESPONSE._serialized_start=5355
  _DEVICEGETWARNINGSRESPONSE._serialized_end=5397
  _DEVICEGETALLDIGITALIOREQUEST._serialized_start=5399
  _DEVICEGETALLDIGITALIOREQUEST._serialized_end=5489
  _DEVICEGETALLDIGITALIORESPONSE._serialized_start=5491
  _DEVICEGETALLDIGITALIORESPONSE._serialized_end=5538
  _DEVICEGETALLANALOGIOREQUEST._serialized_start=5540
  _DEVICEGETALLANALOGIOREQUEST._serialized_end=5629
  _DEVICEGETALLANALOGIORESPONSE._serialized_start=5631
  _DEVICEGETALLANALOGIORESPONSE._serialized_end=5677
  _DEVICEGETDIGITALIOREQUEST._serialized_start=5679
  _DEVICEGETDIGITALIOREQUEST._serialized_end=5790
  _DEVICEGETANALOGIOREQUEST._serialized_start=5792
  _DEVICEGETANALOGIOREQUEST._serialized_end=5902
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_start=5904
  _DEVICESETALLDIGITALOUTPUTSREQUEST._serialized_end=5993
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_start=5995
  _DEVICESETALLANALOGOUTPUTSREQUEST._serialized_end=6083
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_start=6085
  _DEVICESETDIGITALOUTPUTREQUEST._serialized_end=6193
  _DEVICESETANALOGOUTPUTREQUEST._serialized_start=6195
  _DEVICESETANALOGOUTPUTREQUEST._serialized_end=6302
  _SETLOGOUTPUTREQUEST._serialized_start=6304
  _SETLOGOUTPUTREQUEST._serialized_end=6358
  _DEVICEGETSETTINGREQUEST._serialized_start=6360
  _DEVICEGETSETTINGREQUEST._serialized_end=6468
  _DEVICECONVERTSETTINGREQUEST._serialized_start=6471
  _DEVICECONVERTSETTINGREQUEST._serialized_end=6619
  _DEVICESETSETTINGREQUEST._serialized_start=6621
  _DEVICESETSETTINGREQUEST._serialized_end=6744
  _DEVICESETSETTINGSTRREQUEST._serialized_start=6746
  _DEVICESETSETTINGSTRREQUEST._serialized_end=6858
  _PREPARECOMMANDREQUEST._serialized_start=6861
  _PREPARECOMMANDREQUEST._serialized_end=7019
  _LOCKSTEPENABLEREQUEST._serialized_start=7021
  _LOCKSTEPENABLEREQUEST._serialized_end=7123
  _LOCKSTEPDISABLEREQUEST._serialized_start=7125
  _LOCKSTEPDISABLEREQUEST._serialized_end=7239
  _LOCKSTEPSTOPREQUEST._serialized_start=7241
  _LOCKSTEPSTOPREQUEST._serialized_end=7352
  _LOCKSTEPHOMEREQUEST._serialized_start=7354
  _LOCKSTEPHOMEREQUEST._serialized_end=7465
  _LOCKSTEPMOVEREQUEST._serialized_start=7468
  _LOCKSTEPMOVEREQUEST._serialized_end=7821
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_start=4987
  _LOCKSTEPMOVEREQUEST_MOVETYPE._serialized_end=5042
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_start=7823
  _LOCKSTEPWAITUNTILIDLEREQUEST._serialized_end=7948
  _LOCKSTEPEMPTYREQUEST._serialized_start=7950
  _LOCKSTEPEMPTYREQUEST._serialized_end=8037
  _LOCKSTEPAXES._serialized_start=8039
  _LOCKSTEPAXES._serialized_end=8117
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_start=8119
  _LOCKSTEPGETAXISNUMBERSRESPONSE._serialized_end=8165
  _LOCKSTEPGETTWISTSREQUEST._serialized_start=8167
  _LOCKSTEPGETTWISTSREQUEST._serialized_end=8272
  _LOCKSTEPGETTWISTSRESPONSE._serialized_start=8274
  _LOCKSTEPGETTWISTSRESPONSE._serialized_end=8317
  _LOCKSTEPGETOFFSETSREQUEST._serialized_start=8319
  _LOCKSTEPGETOFFSETSREQUEST._serialized_end=8425
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_start=8427
  _LOCKSTEPGETOFFSETSRESPONSE._serialized_end=8472
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_start=8474
  _OSCILLOSCOPEADDCHANNELREQUEST._serialized_end=8574
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_start=8576
  _OSCILLOSCOPESTARTSTOPREQUEST._serialized_end=8659
  _OSCILLOSCOPEREADRESPONSE._serialized_start=8661
  _OSCILLOSCOPEREADRESPONSE._serialized_end=8705
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_start=8707
  _OSCILLOSCOPEDATAIDENTIFIER._serialized_end=8752
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_start=8754
  _OSCILLOSCOPECAPTUREPROPERTIES._serialized_end=8823
  _OSCILLOSCOPEDATAGETREQUEST._serialized_start=8825
  _OSCILLOSCOPEDATAGETREQUEST._serialized_end=8884
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_start=8886
  _OSCILLOSCOPEDATAGETSAMPLETIMEREQUEST._serialized_end=8970
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_start=8972
  _OSCILLOSCOPEDATAGETSAMPLESRESPONSE._serialized_end=9022
  _STREAMSETUPLIVEREQUEST._serialized_start=9024
  _STREAMSETUPLIVEREQUEST._serialized_end=9119
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_start=9122
  _STREAMSETUPLIVECOMPOSITEREQUEST._serialized_end=9272
  _STREAMSETUPSTOREREQUEST._serialized_start=9274
  _STREAMSETUPSTOREREQUEST._serialized_end=9393
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_start=9396
  _STREAMSETUPSTORECOMPOSITEREQUEST._serialized_end=9570
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_start=9573
  _STREAMSETUPSTOREARBITRARYAXESREQUEST._serialized_end=9711
  _STREAMCALLREQUEST._serialized_start=9713
  _STREAMCALLREQUEST._serialized_end=9812
  _STREAMLINEREQUEST._serialized_start=9815
  _STREAMLINEREQUEST._serialized_end=10063
  _STREAMLINEREQUEST_TYPE._serialized_start=10039
  _STREAMLINEREQUEST_TYPE._serialized_end=10063
  _STREAMARCREQUEST._serialized_start=10066
  _STREAMARCREQUEST._serialized_end=10499
  _STREAMARCREQUEST_TYPE._serialized_start=10039
  _STREAMARCREQUEST_TYPE._serialized_end=10063
  _STREAMCIRCLEREQUEST._serialized_start=10502
  _STREAMCIRCLEREQUEST._serialized_end=10837
  _STREAMCIRCLEREQUEST_TYPE._serialized_start=10039
  _STREAMCIRCLEREQUEST_TYPE._serialized_end=10063
  _STREAMWAITDIGITALINPUTREQUEST._serialized_start=10839
  _STREAMWAITDIGITALINPUTREQUEST._serialized_end=10966
  _STREAMWAITANALOGINPUTREQUEST._serialized_start=10969
  _STREAMWAITANALOGINPUTREQUEST._serialized_end=11114
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_start=11116
  _STREAMSETDIGITALOUTPUTREQUEST._serialized_end=11243
  _STREAMSETANALOGOUTPUTREQUEST._serialized_start=11245
  _STREAMSETANALOGOUTPUTREQUEST._serialized_end=11371
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_start=11373
  _STREAMTOGGLEDIGITALOUTPUTREQUEST._serialized_end=11488
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_start=11490
  _STREAMSETALLDIGITALOUTPUTSREQUEST._serialized_end=11598
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_start=11600
  _STREAMSETALLANALOGOUTPUTSREQUEST._serialized_end=11707
  _STREAMWAITREQUEST._serialized_start=11709
  _STREAMWAITREQUEST._serialized_end=11813
  _STREAMWAITUNTILIDLEREQUEST._serialized_start=11815
  _STREAMWAITUNTILIDLEREQUEST._serialized_end=11930
  _STREAMEMPTYREQUEST._serialized_start=11932
  _STREAMEMPTYREQUEST._serialized_end=12009
  _STREAMGETAXESRESPONSE._serialized_start=12011
  _STREAMGETAXESRESPONSE._serialized_end=12094
  _STREAMGETMAXSPEEDREQUEST._serialized_start=12096
  _STREAMGETMAXSPEEDREQUEST._serialized_end=12193
  _STREAMSETMAXSPEEDREQUEST._serialized_start=12195
  _STREAMSETMAXSPEEDREQUEST._serialized_end=12311
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=12313
  _STREAMGETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=12427
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_start=12430
  _STREAMSETMAXTANGENTIALACCELERATIONREQUEST._serialized_end=12581
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=12583
  _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=12698
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_start=12701
  _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST._serialized_end=12854
  _STREAMBUFFERGETCONTENTREQUEST._serialized_start=12856
  _STREAMBUFFERGETCONTENTREQUEST._serialized_end=12944
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_start=12946
  _STREAMBUFFERGETCONTENTRESPONSE._serialized_end=13000
  _STREAMBUFFERERASEREQUEST._serialized_start=13002
  _STREAMBUFFERERASEREQUEST._serialized_end=13085
  _STREAMGENERICCOMMANDREQUEST._serialized_start=13087
  _STREAMGENERICCOMMANDREQUEST._serialized_end=13190
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_start=13192
  _STREAMGENERICCOMMANDBATCHREQUEST._serialized_end=13298
  _BINARYREPLYONLYEVENT._serialized_start=13300
  _BINARYREPLYONLYEVENT._serialized_end=13399
  _OPENBINARYINTERFACEREQUEST._serialized_start=13402
  _OPENBINARYINTERFACEREQUEST._serialized_end=13589
  _UNKNOWNBINARYRESPONSEEVENT._serialized_start=13591
  _UNKNOWNBINARYRESPONSEEVENT._serialized_end=13696
  _GENERICBINARYREQUEST._serialized_start=13699
  _GENERICBINARYREQUEST._serialized_end=13829
  _BINARYMESSAGE._serialized_start=13831
  _BINARYMESSAGE._serialized_end=13901
  _BINARYMESSAGECOLLECTION._serialized_start=13903
  _BINARYMESSAGECOLLECTION._serialized_end=13985
  _DEVICEEMPTYREQUEST._serialized_start=13987
  _DEVICEEMPTYREQUEST._serialized_end=14045
  _BINARYDEVICEIDENTITY._serialized_start=14048
  _BINARYDEVICEIDENTITY._serialized_end=14393
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_start=14344
  _BINARYDEVICEIDENTITY_DEVICETYPE._serialized_end=14393
  _BINARYGENERICWITHUNITSREQUEST._serialized_start=14396
  _BINARYGENERICWITHUNITSREQUEST._serialized_end=14549
  _BINARYDEVICEHOMEREQUEST._serialized_start=14551
  _BINARYDEVICEHOMEREQUEST._serialized_end=14645
  _BINARYDEVICEMOVEREQUEST._serialized_start=14648
  _BINARYDEVICEMOVEREQUEST._serialized_end=14866
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_start=4987
  _BINARYDEVICEMOVEREQUEST_MOVETYPE._serialized_end=5024
  _BINARYDEVICESTOPREQUEST._serialized_start=14868
  _BINARYDEVICESTOPREQUEST._serialized_end=14962
  _BINARYDEVICEDETECTREQUEST._serialized_start=14964
  _BINARYDEVICEDETECTREQUEST._serialized_end=15039
  _BINARYDEVICEDETECTRESPONSE._serialized_start=15041
  _BINARYDEVICEDETECTRESPONSE._serialized_end=15086
  _BINARYDEVICEGETSETTINGREQUEST._serialized_start=15088
  _BINARYDEVICEGETSETTINGREQUEST._serialized_end=15188
  _BINARYDEVICESETSETTINGREQUEST._serialized_start=15190
  _BINARYDEVICESETSETTINGREQUEST._serialized_end=15305
  _CUSTOMINTERFACEREADREQUEST._serialized_start=15307
  _CUSTOMINTERFACEREADREQUEST._serialized_end=15357
  _CUSTOMINTERFACEWRITEREQUEST._serialized_start=15359
  _CUSTOMINTERFACEWRITEREQUEST._serialized_end=15427
  _CUSTOMINTERFACEOPENRESPONSE._serialized_start=15429
  _CUSTOMINTERFACEOPENRESPONSE._serialized_end=15480
  _CUSTOMINTERFACECLOSEREQUEST._serialized_start=15482
  _CUSTOMINTERFACECLOSEREQUEST._serialized_end=15556
  _CANSETSTATEREQUEST._serialized_start=15558
  _CANSETSTATEREQUEST._serialized_end=15645
  _CANSETSTATEAXISRESPONSE._serialized_start=15647
  _CANSETSTATEAXISRESPONSE._serialized_end=15708
  _CANSETSTATEDEVICERESPONSE._serialized_start=15710
  _CANSETSTATEDEVICERESPONSE._serialized_end=15822
  _SETSTATEREQUEST._serialized_start=15824
  _SETSTATEREQUEST._serialized_end=15929
  _SERVOTUNINGREQUEST._serialized_start=15931
  _SERVOTUNINGREQUEST._serialized_end=16021
  _SERVOTUNINGPARAM._serialized_start=16023
  _SERVOTUNINGPARAM._serialized_end=16070
  _PARAMSETINFO._serialized_start=16072
  _PARAMSETINFO._serialized_end=16175
  _SETSERVOTUNINGREQUEST._serialized_start=16178
  _SETSERVOTUNINGREQUEST._serialized_end=16336
  _LOADPARAMSET._serialized_start=16338
  _LOADPARAMSET._serialized_end=16448
  _SETSERVOTUNINGPIDREQUEST._serialized_start=16451
  _SETSERVOTUNINGPIDREQUEST._serialized_end=16592
  _PIDTUNING._serialized_start=16594
  _PIDTUNING._serialized_end=16681
  _SETSIMPLETUNING._serialized_start=16684
  _SETSIMPLETUNING._serialized_end=16878
  _SIMPLETUNINGPARAMDEFINITION._serialized_start=16880
  _SIMPLETUNINGPARAMDEFINITION._serialized_end=16980
  _GETSIMPLETUNINGPARAMDEFINITIONRESPONSE._serialized_start=16982
  _GETSIMPLETUNINGPARAMDEFINITIONRESPONSE._serialized_end=17091
  _TRANSLATORCREATEREQUEST._serialized_start=17094
  _TRANSLATORCREATEREQUEST._serialized_end=17243
  _TRANSLATORCREATERESPONSE._serialized_start=17245
  _TRANSLATORCREATERESPONSE._serialized_end=17294
  _TRANSLATORAXISDEFINITION._serialized_start=17296
  _TRANSLATORAXISDEFINITION._serialized_end=17375
  _TRANSLATORDEFINITION._serialized_start=17378
  _TRANSLATORDEFINITION._serialized_end=17539
  _TRANSLATORCONFIG._serialized_start=17542
  _TRANSLATORCONFIG._serialized_end=17714
  _TRANSLATORAXISMAPPING._serialized_start=17716
  _TRANSLATORAXISMAPPING._serialized_end=17780
  _TRANSLATORAXISTRANSFORMATION._serialized_start=17782
  _TRANSLATORAXISTRANSFORMATION._serialized_end=17908
  _TRANSLATORTRANSLATEREQUEST._serialized_start=17910
  _TRANSLATORTRANSLATEREQUEST._serialized_end=17976
  _TRANSLATEMESSAGE._serialized_start=17978
  _TRANSLATEMESSAGE._serialized_end=18051
  _TRANSLATORTRANSLATERESPONSE._serialized_start=18053
  _TRANSLATORTRANSLATERESPONSE._serialized_end=18160
  _GCODESYNTAXEXCEPTIONDATA._serialized_start=18162
  _GCODESYNTAXEXCEPTIONDATA._serialized_end=18226
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_start=18228
  _GCODEEXECUTIONEXCEPTIONDATA._serialized_end=18295
  _TRANSLATORFLUSHLIVEREQUEST._serialized_start=18297
  _TRANSLATORFLUSHLIVEREQUEST._serialized_end=18373
  _TRANSLATORFLUSHRESPONSE._serialized_start=18375
  _TRANSLATORFLUSHRESPONSE._serialized_end=18418
  _TRANSLATORCREATELIVEREQUEST._serialized_start=18421
  _TRANSLATORCREATELIVEREQUEST._serialized_end=18565
  _TRANSLATORCREATEFROMDEVICEREQUEST._serialized_start=18568
  _TRANSLATORCREATEFROMDEVICEREQUEST._serialized_end=18713
  _TRANSLATOREMPTYREQUEST._serialized_start=18715
  _TRANSLATOREMPTYREQUEST._serialized_end=18762
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_start=18764
  _TRANSLATORSETTRAVERSERATEREQUEST._serialized_end=18858
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_start=18860
  _TRANSLATORSETAXISPOSITIONREQUEST._serialized_end=18963
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_start=18965
  _TRANSLATORGETAXISPOSITIONREQUEST._serialized_end=19050
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_start=19052
  _TRANSLATORGETAXISOFFSETREQUEST._serialized_end=19162
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_start=19164
  _TRANSLATORSETFEEDRATEOVERRIDEREQUEST._serialized_end=19246
  _DEVICESETSTORAGEREQUEST._serialized_start=19248
  _DEVICESETSTORAGEREQUEST._serialized_end=19369
  _DEVICEGETSTORAGEREQUEST._serialized_start=19371
  _DEVICEGETSTORAGEREQUEST._serialized_end=19477
  _DEVICESETSTORAGENUMBERREQUEST._serialized_start=19479
  _DEVICESETSTORAGENUMBERREQUEST._serialized_end=19590
  _DEVICESETSTORAGEBOOLREQUEST._serialized_start=19592
  _DEVICESETSTORAGEBOOLREQUEST._serialized_end=19701
  _DEVICESTORAGEREQUEST._serialized_start=19703
  _DEVICESTORAGEREQUEST._serialized_end=19790
  _DEVICESETUNITCONVERSIONSREQUEST._serialized_start=19793
  _DEVICESETUNITCONVERSIONSREQUEST._serialized_end=19954
  _CONVERSIONFACTOR._serialized_start=19956
  _CONVERSIONFACTOR._serialized_end=20020
# @@protoc_insertion_point(module_scope)
