# This file is generated from the Zaber device database. Do not manually edit this file.
# pylint: disable=line-too-long

from enum import Enum


class Units(Enum):
    NATIVE = ''

    LENGTH_METRES = 'Length:metres'
    LENGTH_CENTIMETRES = 'Length:centimetres'
    LENGTH_MILLIMETRES = 'Length:millimetres'
    LENGTH_MICROMETRES = 'Length:micrometres'
    LENGTH_NANOMETRES = 'Length:nanometres'
    LENGTH_INCHES = 'Length:inches'

    VELOCITY_METRES_PER_SECOND = 'Velocity:metres per second'
    VELOCITY_CENTIMETRES_PER_SECOND = 'Velocity:centimetres per second'
    VELOCITY_MILLIMETRES_PER_SECOND = 'Velocity:millimetres per second'
    VELOCITY_MICROMETRES_PER_SECOND = 'Velocity:micrometres per second'
    VELOCITY_NANOMETRES_PER_SECOND = 'Velocity:nanometres per second'
    VELOCITY_INCHES_PER_SECOND = 'Velocity:inches per second'

    ACCELERATION_METRES_PER_SECOND_SQUARED = 'Acceleration:metres per second squared'
    ACCELERATION_CENTIMETRES_PER_SECOND_SQUARED = 'Acceleration:centimetres per second squared'
    ACCELERATION_MILLIMETRES_PER_SECOND_SQUARED = 'Acceleration:millimetres per second squared'
    ACCELERATION_MICROMETRES_PER_SECOND_SQUARED = 'Acceleration:micrometres per second squared'
    ACCELERATION_NANOMETRES_PER_SECOND_SQUARED = 'Acceleration:nanometres per second squared'
    ACCELERATION_INCHES_PER_SECOND_SQUARED = 'Acceleration:inches per second squared'

    ANGLE_DEGREES = 'Angle:degrees'
    ANGLE_RADIANS = 'Angle:radians'

    ANGULAR_VELOCITY_DEGREES_PER_SECOND = 'Angular Velocity:degrees per second'
    ANGULAR_VELOCITY_RADIANS_PER_SECOND = 'Angular Velocity:radians per second'

    ANGULAR_ACCELERATION_DEGREES_PER_SECOND_SQUARED = 'Angular Acceleration:degrees per second squared'
    ANGULAR_ACCELERATION_RADIANS_PER_SECOND_SQUARED = 'Angular Acceleration:radians per second squared'

    AC_ELECTRIC_CURRENT_AMPERES_PEAK = 'AC Electric Current:amperes peak'
    AC_ELECTRIC_CURRENT_AMPERES_RMS = 'AC Electric Current:amperes RMS'

    PERCENT_PERCENT = 'Percent:percent'

    DC_ELECTRIC_CURRENT_AMPERES = 'DC Electric Current:amperes'

    FORCE_NEWTONS = 'Force:newtons'
    FORCE_MILLINEWTONS = 'Force:millinewtons'
    FORCE_POUNDS_FORCE = 'Force:pounds-force'
    FORCE_KILONEWTONS = 'Force:kilonewtons'

    TIME_SECONDS = 'Time:seconds'
    TIME_MILLISECONDS = 'Time:milliseconds'
    TIME_MICROSECONDS = 'Time:microseconds'

    TORQUE_NEWTON_METRES = 'Torque:newton metres'
    TORQUE_NEWTON_CENTIMETRES = 'Torque:newton centimetres'
    TORQUE_POUND_FORCE_FEET = 'Torque:pound-force-feet'
    TORQUE_OUNCE_FORCE_INCHES = 'Torque:ounce-force-inches'

    INERTIA_GRAMS = 'Inertia:grams'
    INERTIA_KILOGRAMS = 'Inertia:kilograms'
    INERTIA_MILLIGRAMS = 'Inertia:milligrams'
    INERTIA_POUNDS = 'Inertia:pounds'
    INERTIA_OUNCES = 'Inertia:ounces'

    ROTATIONAL_INERTIA_GRAM_SQUARE_METRE = 'Rotational Inertia:gram-square metre'
    ROTATIONAL_INERTIA_KILOGRAM_SQUARE_METRE = 'Rotational Inertia:kilogram-square metre'
    ROTATIONAL_INERTIA_POUND_SQUARE_FEET = 'Rotational Inertia:pound-square-feet'

    FORCE_CONSTANT_NEWTONS_PER_AMP = 'Force Constant:newtons per amp'
    FORCE_CONSTANT_MILLINEWTONS_PER_AMP = 'Force Constant:millinewtons per amp'
    FORCE_CONSTANT_KILONEWTONS_PER_AMP = 'Force Constant:kilonewtons per amp'
    FORCE_CONSTANT_POUNDS_FORCE_PER_AMP = 'Force Constant:pounds-force per amp'

    TORQUE_CONSTANT_NEWTON_METRES_PER_AMP = 'Torque Constant:newton metres per amp'
    TORQUE_CONSTANT_MILLINEWTON_METRES_PER_AMP = 'Torque Constant:millinewton metres per amp'
    TORQUE_CONSTANT_KILONEWTON_METRES_PER_AMP = 'Torque Constant:kilonewton metres per amp'
    TORQUE_CONSTANT_POUND_FORCE_FEET_PER_AMP = 'Torque Constant:pound-force-feet per amp'

    VOLTAGE_VOLTS = 'Voltage:volts'
    VOLTAGE_MILLIVOLTS = 'Voltage:millivolts'
    VOLTAGE_MICROVOLTS = 'Voltage:microvolts'

    CURRENT_CONTROLLER_PROPORTIONAL_GAIN_VOLTS_PER_AMP = 'Current Controller Proportional Gain:volts per amp'
    CURRENT_CONTROLLER_PROPORTIONAL_GAIN_MILLIVOLTS_PER_AMP = 'Current Controller Proportional Gain:millivolts per amp'
    CURRENT_CONTROLLER_PROPORTIONAL_GAIN_MICROVOLTS_PER_AMP = 'Current Controller Proportional Gain:microvolts per amp'

    CURRENT_CONTROLLER_INTEGRAL_GAIN_VOLTS_PER_AMP_PER_SECOND = 'Current Controller Integral Gain:volts per amp per second'
    CURRENT_CONTROLLER_INTEGRAL_GAIN_MILLIVOLTS_PER_AMP_PER_SECOND = 'Current Controller Integral Gain:millivolts per amp per second'
    CURRENT_CONTROLLER_INTEGRAL_GAIN_MICROVOLTS_PER_AMP_PER_SECOND = 'Current Controller Integral Gain:microvolts per amp per second'

    CURRENT_CONTROLLER_DERIVATIVE_GAIN_VOLTS_SECOND_PER_AMP = 'Current Controller Derivative Gain:volts second per amp'
    CURRENT_CONTROLLER_DERIVATIVE_GAIN_MILLIVOLTS_SECOND_PER_AMP = 'Current Controller Derivative Gain:millivolts second per amp'
    CURRENT_CONTROLLER_DERIVATIVE_GAIN_MICROVOLTS_SECOND_PER_AMP = 'Current Controller Derivative Gain:microvolts second per amp'

    RESISTANCE_KILOOHMS = 'Resistance:kiloohms'
    RESISTANCE_OHMS = 'Resistance:ohms'
    RESISTANCE_MILLIOHMS = 'Resistance:milliohms'
    RESISTANCE_MICROOHMS = 'Resistance:microohms'
    RESISTANCE_NANOOHMS = 'Resistance:nanoohms'

    INDUCTANCE_HENRIES = 'Inductance:henries'
    INDUCTANCE_MILLIHENRIES = 'Inductance:millihenries'
    INDUCTANCE_MICROHENRIES = 'Inductance:microhenries'
    INDUCTANCE_NANOHENRIES = 'Inductance:nanohenries'

    VOLTAGE_CONSTANT_VOLT_SECONDS_PER_RADIAN = 'Voltage Constant:volt seconds per radian'
    VOLTAGE_CONSTANT_MILLIVOLT_SECONDS_PER_RADIAN = 'Voltage Constant:millivolt seconds per radian'
    VOLTAGE_CONSTANT_MICROVOLT_SECONDS_PER_RADIAN = 'Voltage Constant:microvolt seconds per radian'
